@@ -225,9 +225,7 @@ const char *filename;
 
          if ( (TreatAsSpooled) || (matchInList(magiclist,magiccount,filename,FALSE)) )
          {
-           appendUname = TRUE;
-	   return TRUE;
-	    
+            return TRUE;
    	 }
 	return FALSE;
 }
@@ -246,18 +244,15 @@ const char *mbox;
 
 	sprintf(tempfn, "%s%s", default_temp, temp_mbox);
         cp = basename(mbox);
-	if (strcmp(cp, "mbox") == 0 || strcmp(cp, "mailbox") == 0 ||
+/*	if (strcmp(cp, "mbox") == 0 || strcmp(cp, "mailbox") == 0 ||
 		strcmp(cp, "inbox") == 0 || *cp == '.')
 	    strcat(tempfn, user_name);
 	  else
-	    strcat(tempfn, cp);
+ */
+       strcat(tempfn, cp);
 	   
-	  if (appendUname)
-          {
-	     strcat(tempfn, ".");
-	     strcat(tempfn, user_name);
-	     appendUname = FALSE; /* unset it once it's used */
-	  }
+        strcat(tempfn, ".");
+        strcat(tempfn, user_name);
 	   
 	      
 }
@@ -691,8 +686,8 @@ int add_new_only;
 	    }
 	    else if (fast_header_cmp(buffer, "Message-Id", (char *)NULL)) {
 	      buffer[line_bytes - 1] = '\0';
-	      strcpy(current_header->messageid,
-		     (char *) buffer + 12);
+	      strfcpy(current_header->messageid,
+		     (char *) buffer + 12, STRING);
 	    }
 
 	    else if (fast_header_cmp(buffer, "Content-Length", (char *)NULL)) {
