@@ -133,6 +133,8 @@ char *new_address, *full_address;
 	  strcpy(full_address, new_address);
 	else {
 	  len = strlen(full_address);
+	   if (len+strlen(new_address)+3 >= VERY_LONG_STRING)
+	      return(0);
 	  full_address[len  ] = ',';
 	  full_address[len+1] = ' ';
 	  full_address[len+2] = '\0';
@@ -210,7 +212,8 @@ char *return_address, *full_address;
       while ((line_len = mail_gets(next_line, SLEN, curr_folder.fp)) != 0 &&
 	      whitespace(next_line[0])) {
 	no_ret(buf);
-	strcat(buf, next_line); /* Append continuation line */
+	 if (strlen(buf)+strlen(next_line)+1 < VERY_LONG_STRING)
+	    strcat(buf, next_line); /* Append continuation line */
 
 	if (next_line[line_len - 1] == '\n')
 	  lines--;
@@ -256,14 +259,16 @@ char *return_address, *full_address;
 	if (qchloc(address, '@') >= 0) {
 	  if (optimize_and_add(address, full_address) == 0 &&
 	      comment[0] != '\0')
-	    sprintf(full_address + strlen(full_address), " (%s)", comment);
+	     if (strlen(full_address)+strlen(comment)+4 < VERY_LONG_STRING)
+	        sprintf(full_address + strlen(full_address), " (%s)", comment);
 	} else {
 	  if (ret_address[0] == '\0')
 	    translate_return(return_address, ret_address);
 	  sprintf(new_address, ret_address, address);
 	  if (optimize_and_add(new_address, full_address) == 0 &&
 	      comment[0] != '\0')
-	    sprintf(full_address + strlen(full_address), " (%s)", comment);
+	     if (strlen(full_address)+strlen(comment)+4 < VERY_LONG_STRING)
+                 sprintf(full_address + strlen(full_address), " (%s)", comment);
 	}
 
       }
