@@ -685,7 +685,7 @@ int   copy_message;
 	PutLine0(prompt_line,0,
 		catgets(elm_msg_cat, ElmSet, ElmCopiesTo, "Copies to: "));
 
-	if (enter_string(cc_field, LONG_STRING, -1, -1, ESTR_REPLACE) < 0) {
+	if (enter_string(cc_field, VERY_LONG_STRING, -1, -1, ESTR_REPLACE) < 0) {
 	  ClearLine(prompt_line-1);
 	  ClearLine(prompt_line);
 	  
